@@ -81,6 +81,12 @@ def list_files():
     files = [f for f in os.listdir(app.config['UPLOAD_FOLDER']) if os.path.isfile(os.path.join(app.config['UPLOAD_FOLDER'], f))]
     return jsonify(files=files)
 
+# Files getter entrypoint
+@app.route('/file/<filename>', methods=['GET'])
+@salt_token_required
+def get_file(filename):
+    return send_from_directory(app.config['UPLOAD_FOLDER'], filename, as_attachment=True)
+
 # Files delete entrypoint
 @app.route('/files/<filename>', methods=['DELETE'])
 @salt_token_required
